# -*- encoding: utf-8 -*-
##############################################################################
#
#    Addition to OpenERP, Open Source Management Solution   
#    Copyright (C) 2004-2012 Vertel. All Rights Reserved
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from osv import osv, fields
import pooler
import time
import datetime
from tools import DEFAULT_SERVER_DATE_FORMAT, DEFAULT_SERVER_DATETIME_FORMAT, float_compare
from tools.translate import _
import decimal_precision as dp

class project(osv.osv):
    _name = "project.project"
    _description = "Project"
    _inherit = "project.project"

    def _debit_credit_bal_qtty(self, cr, uid, ids, fields, arg, context=None):
        res = {}
        for id in ids:
            res[id] = {
                'contract_balance': 0.0,
                'contract_debit':   0.0,
                'contract_credit':  0.0,
                'contract_quantity':0.0,
                'contract_expcut':  0.0,
                'contract_investment_cost':0.0,
                'contract_costpm':  0.0,
                'contract_costtot': 0.0,
                'contract_roi':     0.0,
                'contract_invtot':  0.0,
                }
            for c in self.browse(cr, uid, id).contract_ids:
                res[id]['contract_balance']  += c.balance
                res[id]['contract_debit']    += c.debit
                res[id]['contract_credit']   += c.credit
                res[id]['contract_quantity'] += c.quantity
                res[id]['contract_expcut']   += c.expcut
                res[id]['contract_investment_cost'] += c.investment_cost
                res[id]['contract_costpm']   += c.costpm
                res[id]['contract_costtot']  += c.costtot
                res[id]['contract_invtot']   += c.inv_tot
                
            if (res[id]['contract_expcut']-res[id]['contract_costpm']) > 0 and res[id]['contract_investment_cost'] > 0:
                res[id]['contract_roi'] = round((res[id]['contract_expcut']-res[id]['contract_costpm'])*12/res[id]['contract_investment_cost']*100,2)

        return res

    _columns = {
                'contract_balance': fields.function(_debit_credit_bal_qtty, type='float', string='Balance', multi='debit_credit_bal_qtty', digits_compute=dp.get_precision('Account')),
                'contract_debit': fields.function(_debit_credit_bal_qtty, type='float', string='Debit', multi='debit_credit_bal_qtty', digits_compute=dp.get_precision('Account')),
                'contract_credit': fields.function(_debit_credit_bal_qtty, type='float', string='Credit', multi='debit_credit_bal_qtty', digits_compute=dp.get_precision('Account')),
                'contract_quantity': fields.function(_debit_credit_bal_qtty, type='float', string='Quantity', multi='debit_credit_bal_qtty'),
                'contract_expcut': fields.function(_debit_credit_bal_qtty, type='float', string='Expenditure cut', multi='debit_credit_bal_qtty',help="Budgeted expenditure cut or alternative cost per month to calculate ROI when there is just indirect returns"),
                'contract_investment_cost': fields.function(_debit_credit_bal_qtty, type='float', string='Investment Cost', multi='debit_credit_bal_qtty'),
                'contract_costpm': fields.function(_debit_credit_bal_qtty, type='float', string='Cost per month', multi='debit_credit_bal_qtty'),
                'contract_costtot': fields.function(_debit_credit_bal_qtty, type='float', string='Total cost', multi='debit_credit_bal_qtty'),
                'contract_roi': fields.function(_debit_credit_bal_qtty, type='float', string='ROI', multi='debit_credit_bal_qtty'),
                'contract_invtot': fields.function(_debit_credit_bal_qtty, type='float', string='Invoices Total', multi='debit_credit_bal_qtty'),
                'contract_ids': fields.one2many('contract.contract', 'device_id', 'Contracts', readonly=False, states={'draft': [('readonly', False)]}),
                'analytic_related': fields.related('analytic_account_id', type='integer', relation='account.analytic.account', string='Analytic Account'),  # For creation of related contracts
                }
    
project()

class contract_contract(osv.osv):
    _name = "contract.contract"
    _inherit = "contract.contract"
    
    def _get_analytic_account(self, cr, uid, id):
        analytic_id = super(contract_contract, self)._get_analytic_account(cr, uid, id)
        c = self.browse(cr,uid,id)
        if c.device_id and c.device_id.id: 
                analytic_id = c.device_id.analytic_account_id.id
        return analytic_id
        
    _columns = {
                'project_id':fields.many2one('project.project','Project',required=False, select=1,ondelete="cascade",),
    }
contract_contract()


# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
